@@ -16,8 +16,9 @@ from protontricks.cli.launch import cli as launch_cli_entrypoint
 from protontricks.cli.main import cli as main_cli_entrypoint
 from protontricks.cli.util import enable_logging
 from protontricks.gui import get_gui_provider
-from protontricks.steam import (APPINFO_STRUCT_HEADER, APPINFO_STRUCT_SECTION,
-                                SteamApp, get_appid_from_shortcut)
+from protontricks.steam import (APPINFO_STRUCT_HEADER,
+                                APPINFO_V28_STRUCT_SECTION, SteamApp,
+                                get_appid_from_shortcut)
 
 
 @pytest.fixture(scope="function", autouse=True)
@@ -377,7 +378,7 @@ def appinfo_factory(steam_dir):
         # Start with the header.
         content = struct.pack(
             APPINFO_STRUCT_HEADER,
-            b"'DV\x07",  # Magic number
+            b"(DV\x07",  # v28 magic number
             1  # Universe, protontricks ignores this
         )
 
@@ -389,15 +390,18 @@ def appinfo_factory(steam_dir):
         access_token = 2
         change_number = 2
         sha_hash = b"0"*20
+        vdf_sha_hash = b"0"*20
+
+        struct_size = struct.calcsize(APPINFO_V28_STRUCT_SECTION)
 
         for appid_, entry in app_entries.items():
             binary_vdf = vdf.binary_dumps(entry)
-            entry_size = len(binary_vdf) + 40
+            entry_size = len(binary_vdf) + (struct_size - 8)
 
             content += struct.pack(
-                APPINFO_STRUCT_SECTION,
+                APPINFO_V28_STRUCT_SECTION,
                 appid_, entry_size, infostate, last_updated, access_token,
-                sha_hash, change_number
+                sha_hash, change_number, vdf_sha_hash
             )
             content += binary_vdf
 
